Returns the FreeSurfer automatic subcortical segmentation (aseg) atlas containing deep brain structures including the thalamus, caudate, putamen, pallidum, hippocampus, amygdala, accumbens, and ventricles.
Value
A ggseg_atlas object with components:
- atlas
Character. Atlas name ("aseg")
- type
Character. Atlas type ("subcortical")
- palette
Named character vector of colours for each region
- data
A
ggseg_data_subcorticalobject containing:- meshes
Data frame with
labelandmeshcolumns- sf
Simple features data frame for 2D rendering
Details
This atlas is derived from FreeSurfer's aseg.mgz volumetric segmentation.
It works with both ggseg (2D slice views) and ggseg3d (3D mesh
visualizations) from a single object.
Structures
The atlas contains bilateral structures:
Thalamus
Caudate
Putamen
Pallidum (globus pallidus)
Hippocampus
Amygdala
Accumbens (nucleus accumbens)
Ventral diencephalon
Plus midline and ventricular structures:
Lateral ventricles
Third ventricle
Fourth ventricle
Brain stem
Cerebellar cortex
Cerebellar white matter
References
Fischl B, Salat DH, Busa E, et al. (2002). Whole brain segmentation: automated labeling of neuroanatomical structures in the human brain. Neuron, 33(3):341-355. doi:10.1016/S0896-6273(02)00569-X
See also
dk() for cortical parcellation,
ggseg_atlas() for the atlas class constructor
Examples
aseg()
#>
#> ── aseg ggseg atlas ────────────────────────────────────────────────────────────
#> Type: subcortical
#> Regions: 18
#> Hemispheres: left, NA, right
#> Views: axial_3, axial_4, axial_5, axial_6, coronal_1, coronal_2, sagittal
#> Palette: ✔
#> Rendering: ✔ ggseg
#> ✔ ggseg3d (meshes)
#> ────────────────────────────────────────────────────────────────────────────────
#> hemi region label names
#> 1 left cerebellum cortex Left-Cerebellum-Cortex cerebellum cortex
#> 2 left thalamus Left-Thalamus thalamus
#> 3 left caudate Left-Caudate caudate
#> 4 left putamen Left-Putamen putamen
#> 5 left pallidum Left-Pallidum pallidum
#> 6 <NA> brain stem Brain-Stem brain stem
#> 7 left hippocampus Left-Hippocampus hippocampus
#> 8 left amygdala Left-Amygdala amygdala
#> 9 left accumbens area Left-Accumbens-area accumbens
#> 10 left ventraldc Left-VentralDC ventral diencephalon
#> structure
#> 1 cerebellum
#> 2 basal ganglia
#> 3 basal ganglia
#> 4 basal ganglia
#> 5 basal ganglia
#> 6 brainstem
#> 7 limbic
#> 8 limbic
#> 9 basal ganglia
#> 10 diencephalon
#> ... with 19 more rows
plot(aseg())
atlas_regions(aseg())
#> [1] "accumbens area" "amygdala" "brain stem"
#> [4] "caudate" "cc anterior" "cc central"
#> [7] "cc mid anterior" "cc mid posterior" "cc posterior"
#> [10] "cerebellum cortex" "choroid plexus" "hippocampus"
#> [13] "optic chiasm" "pallidum" "putamen"
#> [16] "thalamus" "ventraldc" "vessel"