Returns sf data joined with core region info and palette colours. This is the interception point used by ggseg for plotting: it always returns sf geometry, converting from the polygon representation when needed.
See also
Other atlas accessors:
atlas_geom(),
atlas_geometry_type(),
atlas_labels(),
atlas_meshes(),
atlas_palette(),
atlas_polygons(),
atlas_regions(),
atlas_type(),
atlas_vertices(),
atlas_views()
Examples
sf_data <- atlas_sf(dk())
head(sf_data)
#> Simple feature collection with 6 features and 7 fields
#> Geometry type: MULTIPOLYGON
#> Dimension: XY
#> Bounding box: xmin: 56.9868 ymin: 6.453514 xmax: 1625.641 ymax: 79.38795
#> CRS: NA
#> label view hemi region names lobe geometry
#> 180 lh_unknown inferior <NA> <NA> <NA> <NA> MULTIPOLYGON (((59.87309 38...
#> 181 lh_unknown lateral <NA> <NA> <NA> <NA> MULTIPOLYGON (((309.1881 20...
#> 182 lh_unknown medial <NA> <NA> <NA> <NA> MULTIPOLYGON (((561.9354 46...
#> 183 rh_unknown inferior <NA> <NA> <NA> <NA> MULTIPOLYGON (((1056.938 47...
#> 184 rh_unknown lateral <NA> <NA> <NA> <NA> MULTIPOLYGON (((1376.635 14...
#> 185 rh_unknown medial <NA> <NA> <NA> <NA> MULTIPOLYGON (((1539.551 20...
#> colour
#> 180 <NA>
#> 181 <NA>
#> 182 <NA>
#> 183 <NA>
#> 184 <NA>
#> 185 <NA>