atlas_sf: Get atlas data for 2D rendering

View source: R/atlas_accessors.R

atlas_sfR Documentation

Get atlas data for 2D rendering

Description

Returns sf data joined with core region info and palette colours. This is the interception point used by ggseg for plotting: it always returns sf geometry, converting from the polygon representation when needed.

Usage

atlas_sf(atlas)

Arguments

atlas

a ggseg_atlas object

Value

sf data.frame ready for plotting

Examples

sf_data <- atlas_sf(dk())
head(sf_data)

ggseg.formats documentation built on July 2, 2026, 5:07 p.m.