View source: R/atlas_accessors.R
| atlas_sf | R Documentation |
Returns sf data joined with core region info and palette colours. This is the interception point used by ggseg for plotting: it always returns sf geometry, converting from the polygon representation when needed.
atlas_sf(atlas)
atlas |
a ggseg_atlas object |
sf data.frame ready for plotting
sf_data <- atlas_sf(dk())
head(sf_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.