| dk | R Documentation |
Returns the Desikan-Killiany cortical parcellation atlas with 34 regions per hemisphere (68 total) on the cortical surface.
dk()
This atlas is based on the FreeSurfer aparc annotation and is one of the
most widely used cortical parcellations in neuroimaging research.
The atlas works with both ggseg (2D polygon plots) and ggseg3d (3D mesh visualizations) from a single object.
A ggseg_atlas object with components:
Character. Atlas name ("dk")
Character. Atlas type ("cortical")
Named character vector of colours for each region
A ggseg_data_cortical object containing:
Data frame with label and vertices columns
Simple features data frame for 2D rendering
The atlas contains 34 regions per hemisphere including: banks of superior temporal sulcus, caudal anterior cingulate, caudal middle frontal, cuneus, entorhinal, fusiform, inferior parietal, inferior temporal, isthmus cingulate, lateral occipital, lateral orbitofrontal, lingual, medial orbitofrontal, middle temporal, parahippocampal, paracentral, pars opercularis, pars orbitalis, pars triangularis, pericalcarine, postcentral, posterior cingulate, precentral, precuneus, rostral anterior cingulate, rostral middle frontal, superior frontal, superior parietal, superior temporal, supramarginal, frontal pole, temporal pole, transverse temporal, and insula.
Desikan RS, Segonne F, Fischl B, et al. (2006). An automated labeling system for subdividing the human cerebral cortex on MRI scans into gyral based regions of interest. NeuroImage, 31(3):968-980. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.neuroimage.2006.01.021")}
Fischl B, van der Kouwe A, Destrieux C, et al. (2004). Automatically parcellating the human cerebral cortex. Cerebral Cortex, 14(1):11-22. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1093/cercor/bhg087")}
aseg() for subcortical structures,
ggseg_atlas() for the atlas class constructor
Other ggseg_atlases:
aseg(),
suit(),
tracula()
dk()
plot(dk())
atlas_regions(dk())
atlas_labels(dk())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.