powered by
These functions check both the class tag and structural validity by passing the object through ggseg_atlas(). An object that carries the right class but fails validation returns FALSE.
ggseg_atlas()
FALSE
is_ggseg_atlas(x)is_cortical_atlas(x)is_subcortical_atlas(x)is_tract_atlas(x)is_cerebellar_atlas(x)is_brain_atlas(x)
is_cortical_atlas(x)
is_subcortical_atlas(x)
is_tract_atlas(x)
is_cerebellar_atlas(x)
is_brain_atlas(x)
logical
an object
is_ggseg_atlas(dk()) is_cortical_atlas(dk()) is_subcortical_atlas(aseg()) is_tract_atlas(tracula())
Run the code above in your browser using DataLab