Learn R Programming

ggseg.formats (version 0.0.1)

is_ggseg_atlas: Check ggseg atlas class

Description

These functions check both the class tag and structural validity by passing the object through ggseg_atlas(). An object that carries the right class but fails validation returns FALSE.

Usage

is_ggseg_atlas(x)

is_cortical_atlas(x)

is_subcortical_atlas(x)

is_tract_atlas(x)

is_brain_atlas(x)

Value

logical

Arguments

x

an object

Examples

Run this code
is_ggseg_atlas(dk())
is_cortical_atlas(dk())
is_subcortical_atlas(aseg())
is_tract_atlas(tracula())

Run the code above in your browser using DataLab