read_atlas_files: Read in atlas data from all subjects

View source: R/read_freesurfer.R

read_atlas_filesR Documentation

Read in atlas data from all subjects

Description

Recursively reads in all stats files for an atlas (given a unique character string), for all subjects in the subjects directory. Will add hemisphere and subject id to the data.

Usage

read_atlas_files(subjects_dir, atlas)

Arguments

subjects_dir

FreeSurfer subject directory

atlas

unique character combination identifying the atlas

Value

data.frame with stats information for subjects from FreeSurfer

Examples


subj_dir <- "/path/to/freesurfer/7.2.0/subjects/"
read_atlas_files(subj_dir, "aseg.stats")
read_atlas_files(subj_dir, "lh.aparc.stats")


ggseg.formats documentation built on July 2, 2026, 5:07 p.m.