| tracula | R Documentation |
Returns the TRACULA (TRActs Constrained by UnderLying Anatomy) white matter bundle atlas in MNI space.
tracula()
This atlas contains major white matter tracts reconstructed from diffusion MRI using FreeSurfer's TRACULA training data. It works with both ggseg (2D slice projections) and ggseg3d (3D tube mesh visualizations).
A ggseg_atlas object with components:
Character. Atlas name ("tracula")
Character. Atlas type ("tract")
Named character vector of colours for each tract
A ggseg_data_tract object containing:
List of centerline matrices per tract
Simple features data frame for 2D rendering
Yendiki A, Panneck P, Srinivasan P, et al. (2011). Automated probabilistic reconstruction of white-matter pathways in health and disease using an atlas of the underlying anatomy. Frontiers in Neuroinformatics, 5:23. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3389/fninf.2011.00023")}
dk() for cortical parcellation,
aseg() for subcortical structures,
ggseg_atlas() for the atlas class constructor
Other ggseg_atlases:
aseg(),
dk(),
suit()
tracula()
plot(tracula())
atlas_regions(tracula())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.